/*
 * Example for DC Motor 5 click
 *
 * Date         Apr 2017
 * Author       Djordje Rosic
 *
 * Test configuration FT900x :
 *  MCU           :        FT900
 *  Dev. Board    :        EasyFT90x
 *  SW            :        mikroC PRO for FT90x v2.2.1
 *
 * Description :
 *
 * This example demonstrates the use of DC Motor click 5. Button 20 is forward,
 * Button 19 is brake, Button 18 is reverse, and Button 17 is coast.
 *
 * Notes: Pull-down pins 17, 18, 19, and 20, and set button press level for 
 * those pins (port 16 - 23) to high.
 ******************************************************************************/


sbit IN1_PIN at GPIO_PIN56_bit;
sbit IN2_PIN at GPIO_PIN3_bit;


/*
 * System Initialization
 */
void systemInit()
{
    GPIO_Digital_Output(&GPIO_PORT_56_63, _GPIO_PINMASK_0);
    GPIO_Digital_Output(&GPIO_PORT_00_07, _GPIO_PINMASK_3);

    GPIO_Digital_Input(&GPIO_PORT_16_23, _GPIO_PINMASK_1 | _GPIO_PINMASK_2);
    GPIO_Digital_Input(&GPIO_PORT_16_23, _GPIO_PINMASK_3 | _GPIO_PINMASK_4);
}

void main()
{
    systemInit();

    while (1)
    {
        // Coast
        if (Button(&GPIO_PORT_16_23, 1, 1, 1))
        {
            IN1_PIN = 0;
            IN2_PIN = 0;
        }

        // Reverse
        if (Button(&GPIO_PORT_16_23, 2, 1, 1))
        {
            IN1_PIN = 0;
            IN2_PIN = 1;
        }

        // Brake
        if (Button(&GPIO_PORT_16_23, 3, 1, 1))
        {
            IN1_PIN = 1;
            IN2_PIN = 1;
        }

        // Forward
        if (Button(&GPIO_PORT_16_23, 4, 1, 1))
        {
            IN1_PIN = 1;
            IN2_PIN = 0;
        }
    }
}
/************************************************************ END OF FILE *****/